@@ -392,13 +392,19 @@ class Miner(object):
                         self.scaler.update()
                     else:
                         self.optimizer.step()
-                    self.optimizer.zero_grad(set_to_none=True)
+                    if self.amp and self.amp_scaler:
+                        self.optimizer.zero_grad()
+                    else:
+                        self.optimizer.zero_grad(set_to_none=True)
                 total_train_loss += train_loss
                 current_percentage = math.ceil(index / total * 100)
                 if current_percentage != percentage:
                     self._update_progress(train_percentage=f"{percentage}%")
                     percentage = current_percentage
-            self.optimizer.zero_grad(set_to_none=True)
+            if self.amp and self.amp_scaler:
+                self.optimizer.zero_grad()
+            else:
+                self.optimizer.zero_grad(set_to_none=True)
             self._update_progress(force=True, train_percentage=f"{current_percentage}%")
 
             total_train_loss = total_train_loss / train_iters
@@ -432,7 +438,7 @@ class Miner(object):
 
                 total_val_loss = total_val_loss / val_iters
                 self.notify(
-                    f"validation of epoch {self.current_epoch}"
+                    f"validation of epoch {self.current_epoch} "
                     f"finished, loss is {total_val_loss}"
                 )
             if self.drawer is not None:
@@ -493,12 +499,11 @@ class Miner(object):
             total_iters=train_iters,
             iteration=self.current_train_iteration,
         )
-        if self.amp:
+        if self.amp and self.amp_scaler:
             with torch.cuda.amp.autocast():
                 _, loss = self._forward(data)
                 seperate_loss = loss / self.accumulated_iter
-                if self.amp_scaler:
-                    seperate_loss = self.scaler.scale(seperate_loss)
+            seperate_loss = self.scaler.scale(seperate_loss)
         else:
             _, loss = self._forward(data)
             seperate_loss = loss / self.accumulated_iter
